@@ -10,7 +10,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-
 import contextlib
 import functools
 import operator
@@ -28,6 +27,7 @@ from oslo_db import options
 from oslo_db.sqlalchemy import engines
 from oslo_db.sqlalchemy import orm
 from oslo_db.sqlalchemy import utils
+from oslo_db import warning
 
 
 class _symbol(object):
@@ -120,6 +120,14 @@ class _Default(object):
             hasattr(conf_namespace, key)
 
 
+class AlreadyStartedError(TypeError):
+    """Raises when a factory is being asked to initialize a second time.
+
+    Subclasses :class:`.TypeError` for legacy support.
+
+    """
+
+
 class _TransactionFactory(object):
     """A factory for :class:`._TransactionContext` objects.
 
@@ -314,7 +322,8 @@ class _TransactionFactory(object):
     def _configure(self, as_defaults, kw):
 
         if self._started:
-            raise TypeError("this TransactionFactory is already started")
+            raise AlreadyStartedError(
+                "this TransactionFactory is already started")
         not_supported = []
         for k, v in kw.items():
             for dict_ in (
@@ -334,7 +343,7 @@ class _TransactionFactory(object):
             warnings.warn(
                 "Configuration option(s) %r not supported" %
                 sorted(not_supported),
-                exception.NotSupportedWarning
+                warning.NotSupportedWarning
             )
 
     def get_legacy_facade(self):
@@ -464,6 +473,11 @@ class _TransactionFactory(object):
             if self._reader_engine is not self._writer_engine:
                 self._reader_engine.pool.dispose()
 
+    @property
+    def is_started(self):
+        """True if this :class:`._TransactionFactory` is already started."""
+        return self._started
+
     def _start(self, conf=False, connection=None, slave_connection=None):
         with self._start_lock:
             # self._started has been checked on the outside
@@ -777,6 +791,11 @@ class _TransactionContextManager(object):
         """The :class:`._TransactionFactory` associated with this context."""
         return self._root._root_factory
 
+    @property
+    def is_started(self):
+        """True if this manager is already started."""
+        return self._factory.is_started
+
     def configure(self, **kw):
         """Apply configurational options to the factory.
 
@@ -1253,7 +1272,7 @@ class LegacyEngineFacade(object):
         warnings.warn(
             "EngineFacade is deprecated; please use "
             "oslo_db.sqlalchemy.enginefacade",
-            exception.OsloDBDeprecationWarning,
+            warning.OsloDBDeprecationWarning,
             stacklevel=2)
         if _factory:
             self._factory = _factory
